==> maven-scala-plugin-2.3-project.tar.bz2: maven-scala-plugin-2.3/src/main/java/scala/maven/ScalaContinuousCompileMojo.java <==
/*
 * Copyright 2007 scala-tools.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 */
package scala.maven;

import java.io.File;
import java.util.List;

/**
 * Compile the main and test scala source directory in continuous (infinite loop). !! This is an util goal for commandline usage only (Do not use or call it in a pom) !!!
 *
 * @goal cc
 * @requiresDependencyResolution test
 */
public class ScalaContinuousCompileMojo extends ScalaCompilerSupport {

    /**
     * @parameter expression="${project.build.outputDirectory}"
     */
    protected File mainOutputDir;

    /**
     * @parameter expression="${project.build.sourceDirectory}/../scala"
     */
    protected File mainSourceDir;

    /**
     * @parameter expression="${project.build.testOutputDirectory}
     */
    protected File testOutputDir;

    /**
     * @parameter expression="${project.build.testSourceDirectory}/../scala"
     */
    protected File testSourceDir;

    /**
     * Define if fsc should be used, else scalac is used.
     * fsc => scala.tools.nsc.CompileClient, scalac => scala.tools.nsc.Main.
     * @parameter expression="${fsc}" default="true"
     */
    protected boolean useFsc;

    /**
     * @parameter expression="${verbose}" default="false"
     */
    protected boolean verbose;

    @Override
    protected List<String> getClasspathElements() throws Exception {
        throw new UnsupportedOperationException("USELESS");
    }

    @Override
    protected File getOutputDir() throws Exception {
        throw new UnsupportedOperationException("USELESS");
    }

    @Override
    protected File getSourceDir() throws Exception {
        throw new UnsupportedOperationException("USELESS");
    }

    @Override
    protected JavaCommand getScalaCommand() throws Exception {
        JavaCommand jcmd = super.getScalaCommand();
        if (useFsc) {
            jcmd.addOption("verbose", verbose);
        }
        return jcmd;
    }

    @SuppressWarnings("unchecked")
    @Override
    protected final void doExecute() throws Exception {

        mainOutputDir = normalize(mainOutputDir);
        if (!mainOutputDir.exists()) {
            mainOutputDir.mkdirs();
        }
        mainSourceDir = normalize(mainSourceDir);

        testOutputDir = normalize(testOutputDir);
        if (!testOutputDir.exists()) {
            testOutputDir.mkdirs();
        }
        testSourceDir = normalize(testSourceDir);

        if (useFsc) {
            scalaClassName = "scala.tools.nsc.CompileClient";
            StopServer stopServer = new StopServer();
            stopServer.run();
            startNewCompileServer();
            Runtime.getRuntime().addShutdownHook(stopServer);
        }

        getLog().info("wait for files to compile...");
        do {
            int nbFile = 0;
            if (mainSourceDir.exists()) {
                nbFile = compile(mainSourceDir, mainOutputDir, project.getCompileClasspathElements(), true);
            }
            if (testSourceDir.exists()) {
                nbFile += compile(testSourceDir, testOutputDir, project.getTestClasspathElements(), true);
            }
            if (nbFile > 0) {
                getLog().info("wait for files to compile...");
                Thread.sleep(5000);
            } else {
                Thread.sleep(3000);
            }
        } while (true);
    }

    private void startNewCompileServer() throws Exception {
        JavaCommand jcmd = getEmptyScalaCommand("scala.tools.nsc.MainGenericRunner");
        jcmd.addArgs("scala.tools.nsc.CompileServer");
        jcmd.addJvmArgs(jvmArgs);
        jcmd.spawn(displayCmd);
    }

    private class StopServer extends Thread {
        @Override
        public void run() {
            try {
                getLog().info("stop server...");
                JavaCommand jcmd = getScalaCommand();
                jcmd.addArgs("-shutdown");
                jcmd.run(displayCmd, false);
            } catch (Exception exc) {
                //getLog().warn(exc);
            }
        }
    }

}

==> maven-scala-plugin-2.4-project.tar.bz2: maven-scala-plugin-2.4/src/main/java/scala/maven/ScalaContinuousCompileMojo.java <==
/*
 * Copyright 2007 scala-tools.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 */
package scala.maven;

import java.io.File;
import java.util.List;

/**
 * Compile the main and test scala source directory in continuous (infinite loop). !! This is an util goal for commandline usage only (Do not use or call it in a pom) !!!
 *
 * @goal cc
 * @requiresDependencyResolution test
 */
public class ScalaContinuousCompileMojo extends ScalaCompilerSupport {

    /**
     * @parameter expression="${project.build.outputDirectory}"
     */
    protected File mainOutputDir;

    /**
     * @parameter expression="${project.build.sourceDirectory}/../scala"
     */
    protected File mainSourceDir;

    /**
     * @parameter expression="${project.build.testOutputDirectory}
     */
    protected File testOutputDir;

    /**
     * @parameter expression="${project.build.testSourceDirectory}/../scala"
     */
    protected File testSourceDir;

    /**
     * Define if fsc should be used, else scalac is used.
     * fsc => scala.tools.nsc.CompileClient, scalac => scala.tools.nsc.Main.
     * @parameter expression="${fsc}" default="true"
     */
    protected boolean useFsc = true;

    /**
     * @parameter expression="${verbose}" default="false"
     */
    protected boolean verbose = false;

    @Override
    protected List<String> getClasspathElements() throws Exception {
        throw new UnsupportedOperationException("USELESS");
    }

    @Override
    protected File getOutputDir() throws Exception {
        throw new UnsupportedOperationException("USELESS");
    }

    @Override
    protected File getSourceDir() throws Exception {
        throw new UnsupportedOperationException("USELESS");
    }

    @Override
    protected JavaCommand getScalaCommand() throws Exception {
        JavaCommand jcmd = super.getScalaCommand();
        if (useFsc) {
            jcmd.addOption("verbose", verbose);
        }
        return jcmd;
    }

    @SuppressWarnings("unchecked")
    @Override
    protected final void doExecute() throws Exception {

        mainOutputDir = normalize(mainOutputDir);
        if (!mainOutputDir.exists()) {
            mainOutputDir.mkdirs();
        }
        mainSourceDir = normalize(mainSourceDir);

        testOutputDir = normalize(testOutputDir);
        if (!testOutputDir.exists()) {
            testOutputDir.mkdirs();
        }
        testSourceDir = normalize(testSourceDir);

        if (useFsc) {
            getLog().info("use fsc for compilation");
            scalaClassName = "scala.tools.nsc.CompileClient";
            StopServer stopServer = new StopServer();
            stopServer.run();
            startNewCompileServer();
            Runtime.getRuntime().addShutdownHook(stopServer);
        }

        getLog().info("wait for files to compile...");
        do {
            int nbFile = 0;
            if (mainSourceDir.exists()) {
                nbFile = compile(mainSourceDir, mainOutputDir, project.getCompileClasspathElements(), true);
            }
            if (testSourceDir.exists()) {
                nbFile += compile(testSourceDir, testOutputDir, project.getTestClasspathElements(), true);
            }
            if (nbFile > 0) {
                getLog().info("wait for files to compile...");
                Thread.sleep(5000);
            } else {
                Thread.sleep(3000);
            }
        } while (true);
    }

    private void startNewCompileServer() throws Exception {
        JavaCommand jcmd = getEmptyScalaCommand("scala.tools.nsc.MainGenericRunner");
        jcmd.addArgs("scala.tools.nsc.CompileServer");
        jcmd.addJvmArgs(jvmArgs);
        jcmd.addArgs(args);
        jcmd.spawn(displayCmd);
    }

    private class StopServer extends Thread {
        @Override
        public void run() {
            try {
                getLog().info("stop server...");
                JavaCommand jcmd = getScalaCommand();
                jcmd.addArgs("-shutdown");
                jcmd.run(displayCmd, false);
            } catch (Exception exc) {
                //getLog().warn(exc);
            }
        }
    }

}
